#! /bin/bash
# firmware version: 6.3
#
# script to update any 6.1.0.0 or 6.2.0.0 dual boot SLC firmware to 6.3.0.0
# this patch will not install on single boot SLCs, or SLC/B with a CF that is
# smaller than 512MB
#
# this script expects:
#     the firmware update file to be unpacked in /www
#     /tmp/boot to point to the current boot bank
#     /tmp/db-copyconfig to exist if the current config should be copied
#
# this script updates the other boot bank:
#     mounts the other R/O partition and updates it
#     updates both the shared (in /www) and non-shared (in /www/{1,2} files
#     re-customizes any web pages that have been updated
#     deletes any obsolete files
#     for any existing DTDs that have been updated, converts the associated
#         XML file to conform to the new DTD
#     updates the version in /www/xml/server.xml
#     sets the eeprom to boot from the updated bank
#     removes the patch file 
#     


#
# Main program
#

fwrev=6.3.0.0
fwrevmajor=6
fwrevminor=3
scrdir=/www/slcupdate-db-6.3.0.0
tmpdir=/tmp/xwstmp
htmdir=/tmp/xwshtm
tee="/bin/tee -a /tmp/pre-update.txt"
partial=0

/bin/rm -f /tmp/pre-update.txt
/bin/touch /tmp/pre-update.txt

prod=$(/bin/grep \<PRODUCT\> /tmp/boot/xml/config.xml | /bin/awk -F\> '{ print $2 }' | /bin/awk -F\< ' { print $1 }')
modelnum=$(/bin/grep model /etc/ltrx/info | /bin/awk -F= '{ print $2 }' )

# don't do anything if we are on a single boot system
echo "Checking boot configuration..." | $tee
if [ ! -d /www/1 -o ! -d /www/2 ] ; then 
    echo "Single-boot $prod. " | $tee
    echo "This patch may only be installed on a dual-boot $prod." | $tee
    # remove the patch file so XMS will not reboot for firmware update
    /bin/rm -f $scrdir.tgz
    exit 0
fi

if [ ! -d $scrdir ] ; then
    echo "Firmware update directory $scrdir does not exist." | $tee
    echo "Firmware update failed." | $tee
    exit 1
fi

# make sure everything is flushed before we get started
/bin/sync

cd $scrdir

echo "Installing update for $prod firmware revision $fwrev." | $tee

#
# determine bank & partitions
#
# Pre 6.0 filesystem is /dev/hda.  If 6.1 has already been applied to
# the bank we are running on, the filesystem will be /dev/sda
#
# Bank 1: hda1 (/), hda2 (/www), hda3 (kernel)
# Bank 2: hda5 (/), hda2 (/www), hda6 (kernel)

/bin/rm -f /tmp/nextbank

sdafs=0
rootdevbank1="/dev/hda1"
kerneldevbank1="/dev/hda3"
rootdevbank2="/dev/hda5"
kerneldevbank2="/dev/hda6"
rootdevwhole="hda"
if grep -q sda /etc/fstab ; then
    sdafs=1
    rootdevbank1="/dev/sda1"
    kerneldevbank1="/dev/sda3"
    rootdevbank2="/dev/sda5"
    kerneldevbank2="/dev/sda6"
    rootdevwhole="sda"
fi

rootdev=$(/bin/grep dev /etc/fstab | grep -v nfs | grep "0 0" | /bin/awk ' { print $1 }')
bootlink=$(/bin/readlink /tmp/boot)
if [ $rootdev == "$rootdevbank1" -a $bootlink == "/www/1" ] ; then
    currbank=1
    nextbank=2
    mountdev=$rootdevbank2
    kerneldev=$kerneldevbank2
elif [ $rootdev == "$rootdevbank2" -a $bootlink == "/www/2" ] ; then
    currbank=2
    nextbank=1
    mountdev=$rootdevbank1
    kerneldev=$kerneldevbank1
else
    echo "Error: cannot determine current boot bank." | $tee
    # remove the patch file so XMS will not reboot for firmware update
    /bin/rm -f $scrdir.tgz
    exit 1
fi

ln -s /www/$nextbank /tmp/nextbank

echo "Checking firmware version..." | $tee
nextbankrev=$(/bin/grep REV /tmp/nextbank/xml/server.xml | /bin/awk -F\> '{ print $2 }' | /bin/awk -F\< '{ print $1 }')
##if [ $nextbankrev == $fwrev ] ; then
##    echo "" | $tee
##    echo "*** This $prod is already running firmware version $fwrev on Bank $nextbank." | $tee
##    echo "*** The patch will not be installed." | $tee
##    echo "" | $tee
##    # remove the patch file so XMS will not reboot for firmware update
##    /bin/rm -f $scrdir.tgz
##    exit 0
##fi

nextbankrevnum=$(echo -n $nextbankrev | /bin/awk -F'[A-Za-z]' '{ print $1 }' )
nextbankmajor=$(echo -n $nextbankrevnum | /bin/awk -F. '{ print $1 }' )
nextbankminor=$(echo -n $nextbankrevnum | /bin/awk -F. '{ print $2 }' )
nextbankproject=$(echo -n $nextbankrevnum | /bin/awk -F. '{ print $3 }' )
nextbankmaint=$(echo -n $nextbankrevnum | /bin/awk -F. '{ print $4 }' )

currbankrev=$(/bin/grep REV /www/$currbank/xml/server.xml | /bin/awk -F\> '{ print $2 }' | /bin/awk -F\< '{ print $1 }')
currbankrevnum=$(echo -n $currbankrev | /bin/awk -F'[A-Za-z]' '{ print $1 }' )
currbankmajor=$(echo -n $currbankrevnum | /bin/awk -F. '{ print $1 }' )
currbankminor=$(echo -n $currbankrevnum | /bin/awk -F. '{ print $2 }' )

# Patch can only be installed on 6.1.0.0 and 6.2.0.0 or reinstalled on 6.3.0.0
if [ $nextbankmajor -ne 6 ] || [ $nextbankminor -lt 1 -o $nextbankminor -gt 3 ] ; then
    echo "" | $tee
    echo "*** This patch may only be installed on" | $tee
    echo "*** a $prod running firmware version 6.1.0.0 or 6.2.0.0." | $tee
    echo "" | $tee
    # remove the patch file so XMS will not reboot for firmware update
    /bin/rm -f $scrdir.tgz
    exit 0
fi

if [ $nextbankmajor -gt $fwrevmajor ] || [ $nextbankmajor -eq $fwrevmajor -a $nextbankminor -gt $fwrevminor ] ; then
    echo "" | $tee
    echo "*** The currently installed firmware version" | $tee
    echo "*** is greater than the patch version." | $tee
    echo "*** The patch will not be installed." | $tee
    echo "" | $tee
    # remove the patch file so XMS will not reboot for firmware update
    /bin/rm -f $scrdir.tgz
    exit 0
fi

echo "Checking filesystem version..." | $tee
blocks=$(/bin/grep $rootdevwhole /proc/partitions | head -1 | /bin/awk ' { print $3 }')
if [ $blocks -lt $(( 1000 * 500 )) ] ; then
    echo "" | $tee
    echo "*** This patch may only be installed on a $prod with a 512MB" | $tee
    echo "*** filesystem.  The filesystem on this $prod has $blocks blocks." | $tee
    echo "*** The patch will not be installed." | $tee
    echo "" | $tee
    # remove the patch file so XMS will not reboot for firmware update
    /bin/rm -f $scrdir.tgz
    exit 0
fi

# make dirs if they do not exist; clear anything in them if they do exist
/bin/mkdir -p $tmpdir $htmdir
/bin/rm -f $tmpdir/* $htmdir/*

echo "Currently running Bank $currbank, applying firmware update to Bank $nextbank." | $tee

if [ -d /tmp/mnt ] ; then
    if /bin/mount | grep -q /tmp/mnt ; then
        umount /tmp/mnt >> /tmp/pre-update.txt 2>&1
    fi
else
    mkdir -p /tmp/mnt
fi

mount -o rw $mountdev /tmp/mnt >> /tmp/pre-update.txt 2>&1
retval=$?
if [ $retval -ne 0 ]; then
    echo "Error mounting Bank $nextbank R/O partition." | $tee
    echo "Patch installation halted." | $tee
    # remove the patch file so XMS will not reboot for firmware update
    /bin/rm -f $scrdir.tgz
    exit 0
fi

echo -n "Deleting obsolete files..." | $tee

# delete files
# R/O partition: expected to be under /tmp/mnt
if [ -f delete_files_ro ] ; then
    for f in `cat delete_files_ro` ; do
        rm -f -r /tmp/mnt$f
        echo -n "." | $tee
    done
fi
# R/W partition: listed as /www/... (shared) or /tmp/nextbank/... (non-shared)
if [ -f delete_files_rw ] ; then
    for f in `cat delete_files_rw` ; do
        rm -f -r $f
        echo -n "." | $tee
    done
fi

echo "" | $tee

echo -n "Copying new and changed files..." | $tee

# tar files to the 1st partition
for d in bin boot etc lib libexec root sbin usr var x15 ; do
    if [ -d $d ] ; then
        ### cd $d
        ### tar -cf - * | (cd /tmp/mnt/$d ; tar xf -)
        tar -cf - $d | (cd /tmp/mnt ; tar xf -)
        echo -n "." | $tee
        ### cd ..
    fi
done

# copy the appropriate fstab for the boot bank
if [ $nextbank -eq 1 ] ; then
    cp -f fstab.boot1 /tmp/mnt/etc/fstab
else
    cp -f fstab.boot2 /tmp/mnt/etc/fstab
fi

# create /root/.ssh (needed for ShellInABox)
if [ ! -d /tmp/mnt/root/.ssh ] ; then
    mkdir -p /tmp/mnt/root/.ssh
    chmod 700 /tmp/mnt/root/.ssh
fi

# perform first boot actions (refer to first boot actions in /etc/rc)
if [ $prod == "SLB" ] ; then
    # install the SLB SNMP MIB library
    if [ -f lib/libnetsnmpmibs.so.5.1.1.slb ] ; then
      /bin/rm -f /tmp/mnt/lib/libnetsnmpmibs.so.5.1.1
      /bin/mv /tmp/mnt/lib/libnetsnmpmibs.so.5.1.1.slb /tmp/mnt/lib/libnetsnmpmibs.so.5.1.1
    fi
else 
    # SLC
    # remove outlet options from clip.xml for non-SLB models
    sed -i '/REMOVE FOR NONSLB/,+3d' /tmp/mnt/x15/clip.xml
    # remove unneeded snmp mib library
    rm -f /tmp/mnt/lib/libnetsnmpmibs.so.5.1.1.slb
fi
if [ $modelnum -ge 49 -a $modelnum -le 97 ] ; then
    # customize CLI for USB
    sed -i '/START REMOVE FOR USB/,/END REMOVE FOR USB/d' /tmp/mnt/x15/clip.xml
    sed -i 's/pccardslot/usbport/g' /tmp/mnt/x15/clip.xml
    sed -i 's/pccardlogging/usblogging/g' /tmp/mnt/x15/clip.xml
    sed -i 's/pccardmaxfiles/usbmaxfiles/g' /tmp/mnt/x15/clip.xml
    sed -i 's/pccardmaxsize/usbmaxsize/g' /tmp/mnt/x15/clip.xml
    sed -i 's/pccard/usb/g' /tmp/mnt/x15/clip.xml
else
    # customize CLI for PC Card
    sed -i '/START REMOVE FOR PCCARD/,/END REMOVE FOR PCCARD/d' /tmp/mnt/x15/clip.xml
fi
#end first boot actions

# lots of updates, let's flush again
/bin/sync

# tar files to the 2nd (read-write) partition
if [ -d www ] ; then
    cd www

    echo "." | $tee

    # if network directory is empty, delete it so network .htm 
    # customization (below) does not happen.
    if [ ! "$(ls -A network)" ] ; then
        rmdir network
    fi

    # customize web files
    # read values from config.xml, to be used for customizations
    # for dual-boot, use the values in the current boot bank, as they should
    # be the same as what is in the next boot bank (or will be in the next
    # boot bank, if it has never been booted)
    company=$(/bin/grep COMPANY /tmp/boot/xml/config.xml | /bin/awk -F\> '{ print $2 }' | /bin/awk -F\< ' { print $1 }')
    product=$(/bin/grep \<PRODUCT\> /tmp/boot/xml/config.xml | /bin/awk -F\> '{ print $2 }' | /bin/awk -F\< ' { print $1 }')
    productlong=$(/bin/grep PRODUCTLONG /tmp/boot/xml/config.xml | /bin/awk -F\> '{ print $2 }' | /bin/awk -F\< ' { print $1 }')
    model=$(/bin/grep MODEL /tmp/boot/xml/config.xml | /bin/awk -F\> '{ print $2 }' | /bin/awk -F\< ' { print $1 }')
    website=$(/bin/grep WEBSITE /tmp/boot/xml/config.xml | /bin/awk -F\> '{ print $2 }' | /bin/awk -F\< ' { print $1 }')
    echo -e "Re-customizing with $company, $product, $productlong,\n                    $model, $website" | $tee

    # determine number of ports
    if [ $model == "SLC8" -o $model == "SLB884" ] ; then
        numports=8
    elif [ $model == "SLC16" -o $model == "SLB1684" ] ; then
        numports=16
    elif [ $model == "SLC32" ] ; then
        numports=32
    else
        numports=48
    fi
    modelnum=$(/bin/grep model /etc/ltrx/info | /bin/awk -F= '{ print $2 }' )

    # unpack current web pages for bank, customize updated pages
    # if this file does not exist, the updated pages will also be in
    # /tmp/nextbank/orig/htm.tar.gz
    if [ -f /tmp/nextbank/htm.tgz ] ; then
        tar xzf /tmp/nextbank/htm.tgz -C $htmdir

        # customize files to a temp dir, then copy to $htmdir
        for f in *.htm ; do
            /bin/sed "s/Lantronix SLC48/$company $model/g
                 s/SecureLinx Console Manager/$productlong/g
                 s/SLC48/$model/g
                 s/www.lantronix.com/$website/g
                 s/SLC /$product /g" $f > $tmpdir/$f
            /bin/rm -f $htmdir/$f
            /bin/cp $tmpdir/$f $htmdir
        done

        if [ $modelnum -ge 49 -a $modelnum -le 96 ] ; then
            # remove 2nd USB port for some models
            /bin/rm -f $htmdir/pccard*.htm
            for f in $htmdir/*.htm ; do
                /bin/sed -i "/START REMOVE FOR SINGLE USB/,/END REMOVE FOR SINGLE USB/d" $f
            done
        fi

        if [ $modelnum -ge 49 -a $modelnum -le 97 ] ; then
            # customize for USB
            /bin/rm -f $htmdir/pccard*.htm
            for f in $htmdir/*.htm ; do
                /bin/sed -i "s/Upper PC Card Slot/USB Port U1/g
                     s/Lower PC Card Slot/USB Port U2/g
                     s/Upper PC Card/USB Port U1/g
                     s/Lower PC Card/USB Port U2/g
                     s/PC Card Slots/USB Ports/g
                     s/PC Card Slot/USB Port/g
                     s/Upper Slot/Port U1/g
                     s/Lower Slot/Port U2/g
                     s/Slot/Port/g
                     s/PC Card/USB/g
                     /START REMOVE FOR USB/,/END REMOVE FOR USB/d" $f
            done
            /bin/sed -i "s/Upper/U1/g
                         s/Lower/U2/g" $htmdir/devstatus.htm
        else
            # customize for PC Card
            /bin/rm $htmdir/usb*.htm
            for f in $htmdir/*.htm ; do
                /bin/sed -i "/START REMOVE FOR PCCARD/,/END REMOVE FOR PCCARD/d" $f
            done
        fi

        # Update pages that are dependent on number of device ports
        if [ -f banner.htm ] ; then
            # remove extra ports from banner.htm -
            # update the file that was just customized
            /bin/rm -f banner.htm $tmpdir/banner.htm
            /bin/cp $htmdir/banner.htm .
            /bin/awk "{ if ( NF >= 8 && \$6 == \"Device\" && \$7 == \"Port\" )
                     { if ( \$8 <= $numports )
                         print \$0 }
                   else
                     print \$0 }" banner.htm > $tmpdir/banner.htm
            /bin/rm -f $htmdir/banner.htm
            /bin/cp $tmpdir/banner.htm $htmdir
        fi

        if [ -f devports.htm ] ; then
            # remove buttons from devports.htm 
            # update the file that was just updated
            /bin/rm -f devports.htm $tmpdir/devports.htm
            /bin/cp $htmdir/devports.htm .
            /bin/awk "{ if ( NF >= 3 && \$3 == \"name=btn16\" )
                     { if ( $numports >= 32 )
                         print \$0 }
                   else if ( NF >= 3 && \$3 == \"name=btn32\" )
                     { if ( $numports >= 32 )
                         print \$0 }
                   else if ( NF >= 3 && \$3 == \"name=btn48\" )
                     { if ( $numports >= 48 )
                         print \$0 }
                   else if ( NF >= 2 && \$2 == \"SLC8\" )
                     { if ( $numports == 8 )
                         print \$0 }
                   else
                     print \$0 }" devports.htm > $tmpdir/devports.htm
            /bin/rm -f $htmdir/devports.htm
            /bin/cp $tmpdir/devports.htm $htmdir
        fi

        if [ -f datetime.htm -o -f qsetup.htm ] ; then
            # populate timezones in datetime.htm 
            # update the file that was just updated
            dodatetime=0
            doqsetup=0
            if [ -f datetime.htm ] ; then
                dodatetime=1
            fi
            if [ -f qsetup.htm ] ; then
                doqsetup=1
            fi
            /bin/rm -f datetime.htm $tmpdir/datetime.htm
            /bin/cp $htmdir/datetime.htm .
            /bin/rm -f qsetup.htm $tmpdir/qsetup.htm
            /bin/cp $htmdir/qsetup.htm .

            echo "Updating timezones..." | $tee
            # get list of timezone files
            cd /usr/share/zoneinfo
            /bin/rm -f $tmpdir/zonefiles $tmpdir/zonefiles2
            /bin/find . -type f -print | egrep -v 'Factory|right|posix|\.tab' | sort > $tmpdir/zonefiles
            # remove leading './'
            /bin/sed 's/\.\///g' $tmpdir/zonefiles > $tmpdir/zonefiles2
            cd $scrdir/www
            /bin/xws_inserttz
            retval=$?
            if [ $retval -eq 0 ]; then
                if [ $dodatetime -eq 1 ] ; then
                    /bin/rm -f $htmdir/datetime.htm
                    /bin/cp $tmpdir/datetime.htm $htmdir
                fi
                if [ $doqsetup -eq 1 ] ; then
                    /bin/rm -f $htmdir/qsetup.htm
                    /bin/cp $tmpdir/qsetup.htm $htmdir
                fi
            elif [ $retval -eq 1 ]; then
                echo "Cannot open original datetime.htm or qsetup.htm" | $tee
            elif [ $retval -eq 2 ]; then
                echo "Cannot open new datetime.htm or qsetup.htm" | $tee
            elif [ $retval -eq 3 ]; then
                echo "Cannot open temporary timezone list file" | $tee
            fi
        fi

        # remove obsolete files
        /bin/rm -f $htmdir/authremote.htm $htmdir/menu.htm $htmdir/netgateway.htm $htmdir/prescsnetworkdp.htm $htmdir/scsnetworkdp.htm

        # zip up and replace htm.tgz
        /bin/rm -f /tmp/nextbank/htm.tgz
        cd $htmdir
        tar czf /tmp/nextbank/htm.tgz *.htm

        cd $scrdir/www
        /bin/rm -f $tmpdir/* $htmdir/*

    fi

    # web telnet pages
    if [ -d network -a -f /tmp/nextbank/network.tgz ] ; then
        # unpack current web pages for bank
        tar xzf /tmp/nextbank/network.tgz -C $htmdir
        # as of 5.2, the .htm web pages (except for webtelnet.htm and
        # webssh.htm) are no longer needed
        ###/bin/rm -f $htmdir/*.htm
        # customize .htm files
        cd network
        for f in *.htm ; do
            /bin/sed "s/Lantronix SLC48/$company $model/g" $f > $tmpdir/$f
            /bin/rm -f $htmdir/$f
            /bin/cp $tmpdir/$f $htmdir
        done
        /bin/rm -f /tmp/nextbank/network.tgz
        cd $htmdir
        tar czf /tmp/nextbank/network.tgz *.htm
        cd $scrdir/www
    fi

    # we are done with these files in the patch
    rm -rf *.htm network

    # copy all the new/changed files that are not shared between boot banks
    for d in js orig xml xml-defaults ; do
        if [ -d $d ] ; then
            tar -cf - $d | (cd /www/$nextbank ; tar xf -)
        fi
    done

    if [ -d help ] ; then
        tar -cf - help | (cd /www/$nextbank ; tar xf -)
    fi
    if [ -d /www/$nextbank/help-slb ] ; then
        rm -rf /www/$nextbank/help-slb
    fi

    # trim xml-defaults devports.xml if number of ports is less than 48
    if [ -f xml-defaults/devports.xml -a $numports -ne 48 ]; then
        mkdir /tmp/xml
        cp xml-defaults/devports.xml /tmp/xml
        cd /tmp
        /bin/xws_trimdevports $numports
        retval=$?
        if [ $retval -eq 0 ]; then
            /bin/rm -f /tmp/nextbank/xml-defaults/devports.xml
            /bin/cp $tmpdir/devports.xml /tmp/nextbank/xml-defaults
        elif [ $retval -eq 1 ]; then
            echo "Wrong arguments passed to xws_trimdevports" | $tee
        elif [ $retval -eq 2 ]; then
            echo "Cannot open original xml/devports.xml" | $tee
        elif [ $retval -eq 3 ]; then
            echo "Cannot open new devports.xml" | $tee
        fi
        cd $scrdir/www
    fi

    rm -rf help help-slb js orig xml xml-defaults

    if [ -f cert.pem -a -f key.pem ] ; then
        # Installing new certificate
        if [ -f /www/cert.pem.orig -a -f /www/key.pem.orig ] ; then
            # an imported certificate in place already, do not overwrite
            # only copy new certificate backup files
            rm -f cert.pem key.pem
        fi
    fi

    # copy all the new/changed files that are shared between boot banks
    # copying these *cannot* affect the current boot bank which is running
    tar -cf - * | (cd /www ; tar xf -)

    cd $scrdir

fi

# another flush...
/bin/sync

# if there is a u-boot.bin file, touch .updateuboot so that the boot loader
# version will be checked at reboot
if [ -f bin/u-boot.bin ] ; then
    touch /tmp/nextbank/.updateuboot
    bootloaderrev=$(cat etc/uboot.conf | /bin/awk '{ print $2 }' )
    echo "The bootloader will be upgraded to revision $bootloaderrev when $fwrev is booted." | $tee
    echo "The correct bootloader version will not be displayed in 'admin version'" | $tee
    echo "until after the next reboot following the bootloader upgrade." | $tee
fi

# update kernel
if [ -f uImage.NEWHW.gz -a -f uImage.OLDHW.gz ] ; then
    if [ $modelnum -eq 97 ] ; then
        echo "Updating kernel (NEWHW) on device $kerneldev..." | $tee
        /bin/gunzip -d < uImage.NEWHW.gz | /bin/dd of=$kerneldev >> /tmp/pre-update.txt 2>&1
    else
        echo "Updating kernel (OLDHW) on device $kerneldev..." | $tee
        /bin/gunzip -d < uImage.OLDHW.gz | /bin/dd of=$kerneldev >> /tmp/pre-update.txt 2>&1
    fi
    if [ "$?" -eq 0 ] ; then
        echo "Finished updating Bank $nextbank kernel." | $tee
    else
        echo "Error $? updating Bank $nextbank kernel." | $tee
    fi
fi

#
# update devices
#

# No changes for 6.2 or 6.3

#
# convert all XML files to 6.3 format
#

if [ -f /tmp/db-copyconfig ] ; then
    # copy configuration from current bank before continuing
    echo "Copying configuration from bank $currbank..." | $tee
    mv -f /tmp/nextbank/xml/app.xml /tmp/nextbank/xml/app.xml-
    cp -f /www/$currbank/xml/*.xml /tmp/nextbank/xml
    mv -f /tmp/nextbank/xml/app.xml- /tmp/nextbank/xml/app.xml
    rm -rf /tmp/nextbank/xml/keys
    cp -r /www/$currbank/xml/keys /tmp/nextbank/xml/keys
    rm -rf /tmp/nextbank/xml/scripts
    cp -r /www/$currbank/xml/scripts /tmp/nextbank/xml/scripts
    rm -f /tmp/db-copyconfig
    rm -f /tmp/nextbank/.configure /tmp/nextbank/.configureip
    nextbankrev=$(/bin/grep REV /tmp/nextbank/xml/server.xml | /bin/awk -F\> '{ print $2 }' | /bin/awk -F\< '{ print $1 }')
fi

cd $scrdir

# run conversion program to convert XML to the new DTD
echo "Converting XML from $nextbankrev to $fwrev..." | $tee
./convert_xml /tmp/nextbank/xml $nextbankrev $fwrev
retval=$?
if [ $retval -eq 0 ]; then
    echo "XML conversion completed." | $tee
else
    echo "Error converting XML." | $tee
fi


# update firmware revision in server.xml
/bin/sed -i "s/<REV>[\.a-zA-Z0-9]*<\/REV>/<REV>$fwrev<\/REV>/g" /tmp/nextbank/xml/server.xml >> /tmp/pre-update.txt 2>&1
/bin/sed -i "s/<REV>[\.a-zA-Z0-9]*<\/REV>/<REV>$fwrev<\/REV>/g" /tmp/nextbank/xml-defaults/server.xml >> /tmp/pre-update.txt 2>&1

# touch timestamp file
/bin/touch /tmp/nextbank/.timestamp

# flush updates
/bin/sync

# cleanup
umount /tmp/mnt >> /tmp/pre-update.txt 2>&1
rmdir /tmp/mnt
/bin/rm -rf $tmpdir $htmdir

# call eeprom to configure next boot bank and setup link to /www bank dir
/bin/eeprom -s $nextbank >> /dev/null 2>&1
rm -f /tmp/next /tmp/nextbank
ln -s /www/$nextbank /tmp/next

# remove the patch file so XMS will not reboot for firmware update
/bin/rm -f $scrdir.tgz

/bin/echo "Installation of $prod firmware revision $fwrev to Bank $nextbank complete." | $tee
/bin/echo "The $prod is configured to use Bank $nextbank at the next reboot." | $tee

exit 0
